"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const config_1 = require("../../lib/config");
const stack_factory_1 = require("../../lib/stack-factory");
class AddStackCommand extends core_1.Command {
    async run() {
        const config = config_1.ShellConfig.read({}, this);
        await this.execute(config);
    }
    async execute(config) {
        const { flags } = await this.parse();
        if (config.projectConfig === undefined) {
            this.error("No `.fauna-project` found. Create one with `fauna project init`.");
        }
        const stackFactory = new stack_factory_1.StackFactory(this, config);
        await stackFactory.addStack({
            endpoint: flags.endpoint,
            database: flags.database,
            name: flags.name,
            default: flags["set-default"],
            nonInteractive: flags["non-interactive"],
        });
    }
}
AddStackCommand.flags = {
    name: core_1.Flags.string({
        description: "New stack name",
    }),
    endpoint: core_1.Flags.string({
        description: "Endpoint to use in this stack",
    }),
    database: core_1.Flags.string({
        description: "Database path to use in this stack",
    }),
    "non-interactive": core_1.Flags.boolean({
        description: "Disable interaction",
        dependsOn: ["name", "endpoint", "database"],
    }),
    "set-default": core_1.Flags.boolean({
        description: "Set this stack as the default",
    }),
};
AddStackCommand.description = "Add a new stack to `.fauna-project`.";
AddStackCommand.examples = [
    "$ fauna stack add",
    "$ fauna stack add --name my-app --endpoint dev --database my-database",
    "$ fauna stack add --name my-app --endpoint dev --database my-database --set-default",
];
exports.default = AddStackCommand;
