"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const config_1 = require("../../lib/config");
class SelectStackCommand extends core_1.Command {
    async run() {
        const config = config_1.ShellConfig.read({}, this);
        await this.execute(config);
    }
    async execute(config) {
        const { args } = await this.parse();
        if (config.projectConfig === undefined) {
            this.error("No project config found");
        }
        if (!Object.keys(config.projectConfig.stacks).includes(args.stack)) {
            this.error(`Stack ${args.stack} not found in project config. Run \`fauna stack list\` to see available stacks`);
        }
        config.projectConfig.defaultStack = args.stack;
        config.saveProjectConfig();
        console.log(`Selected stack ${args.stack}`);
    }
}
SelectStackCommand.args = {
    stack: core_1.Args.string({
        description: "The new default stack to use",
        required: true,
    }),
};
SelectStackCommand.description = "Update the default stack in `.fauna-project`.";
SelectStackCommand.examples = ["$ fauna stack select my-stack"];
exports.default = SelectStackCommand;
