"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Stack = exports.ProjectConfig = void 0;
const tslib_1 = require("tslib");
const ini = require("ini");
const fs = tslib_1.__importStar(require("fs"));
const _1 = require(".");
// Represents `.fauna-project`
class ProjectConfig {
    /**
     * This method is used to obtain an empty project config when fauna project init is used.
     */
    static initialConfig(fslDir) {
        return new ProjectConfig({}, undefined, fslDir);
    }
    constructor(stacks, defaultStack, schemaDir) {
        this.stacks = stacks;
        this.defaultStack = defaultStack;
        this.schemaDir = schemaDir;
    }
    static fromConfig(config) {
        const defaultStack = config.strOpt(ProjectConfig.DEFAULT_FIELD_NAME);
        const fslDir = config.strOpt(ProjectConfig.SCHEMA_DIRECTORY_FIELD_NAME);
        const stacks = config.objectExists(ProjectConfig.STACK_FIELD_NAME)
            ? Object.fromEntries(config.objectsIn("stack").map(([k, v]) => [k, new Stack(v)]))
            : {};
        if (defaultStack && stacks[defaultStack] === undefined) {
            throw new _1.InvalidConfigError(`Default stack '${defaultStack}' was not found`);
        }
        return new ProjectConfig(stacks, defaultStack, fslDir);
    }
    validate(rootConfig) {
        for (const stack of Object.values(this.stacks)) {
            if (rootConfig.endpoints[stack.endpoint] === undefined) {
                throw new _1.InvalidConfigError(`Endpoint '${stack.endpoint}' not found in ~/.fauna-shell`);
            }
        }
    }
    save(path) {
        const config = {
            ...(this.schemaDir
                ? { [ProjectConfig.SCHEMA_DIRECTORY_FIELD_NAME]: this.schemaDir }
                : {}),
            ...(this.defaultStack
                ? { [ProjectConfig.DEFAULT_FIELD_NAME]: this.defaultStack }
                : {}),
            [ProjectConfig.STACK_FIELD_NAME]: this.stacks,
        };
        const encoded = ini.encode(config);
        fs.writeFileSync(path, encoded);
    }
}
exports.ProjectConfig = ProjectConfig;
ProjectConfig.DEFAULT_FIELD_NAME = "default";
ProjectConfig.SCHEMA_DIRECTORY_FIELD_NAME = "schema_directory";
ProjectConfig.STACK_FIELD_NAME = "stack";
class Stack {
    constructor(config) {
        this.endpoint = config.str("endpoint");
        this.database = config.str("database");
    }
}
exports.Stack = Stack;
