/**
 * Takes a parsed url, an endpoint alias, and the endpoint secret,
 * and saves it to the .ini config file.
 *
 * - If the endpoint already exists, it will be overwritten, after asking confirmation
 *   from the user.
 * - If no other endpoint exists, then the endpoint will be set as the default one.
 */
export function saveEndpointOrError(newEndpoint: any, alias: any, secret: any): Promise<any>;
export function deleteEndpointOrError(alias: any): Promise<any>;
/**
 * Validates that the 'cloud' endpoint points to FAUNA_CLOUD_DOMAIN.
 */
export function validCloudEndpoint(): Promise<any>;
/**
 * Sets `endpoint` as the default endpoint.
 * If `endpoint` doesn't exist, returns an error.
 */
export function setDefaultEndpoint(endpoint: any): Promise<any>;
/**
 * Loads the endpoints from the ~/.fauna-shell file.
 * If the file doesn't exist, returns an empty object.
 */
export function loadEndpoints(): Promise<any>;
export function saveEndpoint(config: any, endpoint: any, alias: any, secret: any): Promise<any>;
/**
 * Returns the full path to the `.fauna-shell` config file
 */
export function getConfigFile(): string;
/**
 * Wraps `fs.readFile` into a Promise.
 */
export function readFile(fileName: any): Promise<any>;
/**
 * Wraps `fs.writeFile` into a Promise.
 */
export function writeFile(fileName: any, data: any, mode: any): Promise<any>;
/**
 * Builds the options provided to the faunajs client.
 * Tries to load the ~/.fauna-shell file and read the default endpoint from there.
 *
 * Assumes that if the file exists, it would have been created by fauna-shell,
 * therefore it would have a defined endpoint.
 *
 * Flags like --host, --port, etc., provided by the CLI take precedence over what's
 * stored in ~/.fauna-shell.
 *
 * The --endpoint flag overries the default endpoint from fauna-shell.
 *
 * If ~/.fauna-shell doesn't exist, tries to build the connection options from the
 * flags passed to the script.
 *
 * It always expect a secret key to be set in ~/.fauna-shell or provided via CLI
 * arguments.
 *
 * @param {Object} cmdFlags - flags passed via the CLI.
 * @param {string} dbScope  - A database name to scope the connection to.
 * @param {string} role     - A user role: 'admin'|'server'|'server-readonly'|'client'.
 */
export function buildConnectionOptions(cmdFlags: Object, dbScope: string, role: string): Promise<any>;
export function runQueries(expressions: any, client: any): any;
